Index: wp-includes/link-template.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/link-template.php	(revision 24067)
+++ wp-includes/link-template.php	(revision )
@@ -13,7 +13,7 @@
  * @uses apply_filters() Calls 'the_permalink' filter on the permalink string.
  */
 function the_permalink() {
-	echo esc_url( apply_filters( 'the_permalink', get_permalink() ) );
+	echo esc_url( apply_filters( 'the_permalink', get_the_permalink() ) );
 }
 
 /**
@@ -72,12 +72,27 @@
  * Retrieve full permalink for current post or post ID.
  *
  * @since 1.0.0
+ * @deprecated 3.6.0
+ * @deprecated Use get_the_permalink()
  *
  * @param int $id Optional. Post ID.
  * @param bool $leavename Optional, defaults to false. Whether to keep post name or page name.
  * @return string
  */
 function get_permalink( $id = 0, $leavename = false ) {
+	return get_the_permalink( $id, $leavename );
+}
+
+/**
+ * Retrieve full permalink for current post or post ID.
+ *
+ * @since 3.6.0
+ *
+ * @param int $id Optional. Post ID.
+ * @param bool $leavename Optional, defaults to false. Whether to keep post name or page name.
+ * @return string
+ */
+function get_the_permalink( $id = 0, $leavename = false ) {
 	$rewritecode = array(
 		'%year%',
 		'%monthnum%',
@@ -222,7 +237,7 @@
 	if ( !empty( $deprecated ) )
 		_deprecated_argument( __FUNCTION__, '1.3' );
 
-	return get_permalink($post_id);
+	return get_the_permalink($post_id);
 }
 
 /**
@@ -307,7 +322,7 @@
 		if ( 'page' == $parent->post_type )
 			$parentlink = _get_page_link( $post->post_parent ); // Ignores page_on_front
 		else
-			$parentlink = get_permalink( $post->post_parent );
+			$parentlink = get_the_permalink( $post->post_parent );
 
 		if ( is_numeric($post->post_name) || false !== strpos(get_option('permalink_structure'), '%category%') )
 			$name = 'attachment/' . $post->post_name; // <permalink>/<int>/ is paged so we use the explicit attachment marker
@@ -475,7 +490,7 @@
 		if ( 'page' == get_option('show_on_front') && $post_id == get_option('page_on_front') )
 			$url = _get_page_link( $post_id );
 		else
-			$url = get_permalink($post_id);
+			$url = get_the_permalink($post_id);
 
 		$url = trailingslashit($url) . 'feed';
 		if ( $feed != get_default_feed() )
@@ -1231,7 +1246,7 @@
 
 	$link = $previous ? "<link rel='prev' title='" : "<link rel='next' title='";
 	$link .= esc_attr( $title );
-	$link .= "' href='" . get_permalink($post) . "' />\n";
+	$link .= "' href='" . get_the_permalink($post) . "' />\n";
 
 	$adjacent = $previous ? 'previous' : 'next';
 	return apply_filters( "{$adjacent}_post_rel_link", $link );
@@ -1393,7 +1408,7 @@
 		$date = mysql2date( get_option( 'date_format' ), $post->post_date );
 		$rel = $previous ? 'prev' : 'next';
 
-		$string = '<a href="' . get_permalink( $post ) . '" rel="'.$rel.'">';
+		$string = '<a href="' . get_the_permalink( $post ) . '" rel="'.$rel.'">';
 		$inlink = str_replace( '%title', $title, $link );
 		$inlink = str_replace( '%date', $date, $inlink );
 		$inlink = $string . $inlink . '</a>';
@@ -1690,7 +1705,7 @@
 
 	$pagenum = (int) $pagenum;
 
-	$result = get_permalink();
+	$result = get_the_permalink();
 
 	if ( 'newest' == get_option('default_comments_page') ) {
 		if ( $pagenum != $max_page ) {
@@ -1823,7 +1838,7 @@
 		'add_fragment' => '#comments'
 	);
 	if ( $wp_rewrite->using_permalinks() )
-		$defaults['base'] = user_trailingslashit(trailingslashit(get_permalink()) . 'comment-page-%#%', 'commentpaged');
+		$defaults['base'] = user_trailingslashit(trailingslashit(get_the_permalink()) . 'comment-page-%#%', 'commentpaged');
 
 	$args = wp_parse_args( $args, $defaults );
 	$page_links = paginate_links( $args );
@@ -2318,7 +2333,7 @@
 	if ( !$id = $wp_the_query->get_queried_object_id() )
 		return;
 
-	$link = get_permalink( $id );
+	$link = get_the_permalink( $id );
 
 	if ( $page = get_query_var('cpage') )
 		$link = get_comments_pagenum_link( $page );
Index: wp-includes/comment-template.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/comment-template.php	(revision 24067)
+++ wp-includes/comment-template.php	(revision )
@@ -497,11 +497,11 @@
 			$args['page'] = ( !empty($in_comment_loop) ) ? get_query_var('cpage') : get_page_of_comment( $comment->comment_ID, $args );
 
 		if ( $wp_rewrite->using_permalinks() )
-			$link = user_trailingslashit( trailingslashit( get_permalink( $comment->comment_post_ID ) ) . 'comment-page-' . $args['page'], 'comment' );
+			$link = user_trailingslashit( trailingslashit( get_the_permalink( $comment->comment_post_ID ) ) . 'comment-page-' . $args['page'], 'comment' );
 		else
-			$link = add_query_arg( 'cpage', $args['page'], get_permalink( $comment->comment_post_ID ) );
+			$link = add_query_arg( 'cpage', $args['page'], get_the_permalink( $comment->comment_post_ID ) );
 	} else {
-		$link = get_permalink( $comment->comment_post_ID );
+		$link = get_the_permalink( $comment->comment_post_ID );
 	}
 
 	return apply_filters( 'get_comment_link', $link . '#comment-' . $comment->comment_ID, $comment, $args );
@@ -516,7 +516,7 @@
  * @return string The link to the comments
  */
 function get_comments_link($post_id = 0) {
-	return apply_filters( 'get_comments_link', get_permalink( $post_id ) . '#comments', $post_id );
+	return apply_filters( 'get_comments_link', get_the_permalink( $post_id ) . '#comments', $post_id );
 }
 
 /**
@@ -705,7 +705,7 @@
  */
 function get_trackback_url() {
 	if ( '' != get_option('permalink_structure') ) {
-		$tb_url = trailingslashit(get_permalink()) . user_trailingslashit('trackback', 'single_trackback');
+		$tb_url = trailingslashit(get_the_permalink()) . user_trailingslashit('trackback', 'single_trackback');
 	} else {
 		$tb_url = get_option('siteurl') . '/wp-trackback.php?p=' . get_the_ID();
 	}
@@ -997,7 +997,7 @@
 		echo '" onclick="wpopen(this.href); return false"';
 	} else { // if comments_popup_script() is not in the template, display simple comment link
 		if ( 0 == $number )
-			echo get_permalink() . '#respond';
+			echo get_the_permalink() . '#respond';
 		else
 			comments_link();
 		echo '"';
@@ -1056,7 +1056,7 @@
 	$link = '';
 
 	if ( get_option('comment_registration') && !$user_ID )
-		$link = '<a rel="nofollow" class="comment-reply-login" href="' . esc_url( wp_login_url( get_permalink() ) ) . '">' . $login_text . '</a>';
+		$link = '<a rel="nofollow" class="comment-reply-login" href="' . esc_url( wp_login_url( get_the_permalink() ) ) . '">' . $login_text . '</a>';
 	else
 		$link = "<a class='comment-reply-link' href='" . esc_url( add_query_arg( 'replytocom', $comment->comment_ID ) ) . "#" . $respond_id . "' onclick='return addComment.moveForm(\"$add_below-$comment->comment_ID\", \"$comment->comment_ID\", \"$respond_id\", \"$post->ID\")'>$reply_text</a>";
 	return apply_filters('comment_reply_link', $before . $link . $after, $args, $comment, $post);
@@ -1107,9 +1107,9 @@
 		return false;
 
 	if ( get_option('comment_registration') && !$user_ID ) {
-		$link = '<a rel="nofollow" href="' . wp_login_url( get_permalink() ) . '">' . $login_text . '</a>';
+		$link = '<a rel="nofollow" href="' . wp_login_url( get_the_permalink() ) . '">' . $login_text . '</a>';
 	} else {
-		$link = "<a rel='nofollow' class='comment-reply-link' href='" . get_permalink($post->ID) . "#$respond_id' onclick='return addComment.moveForm(\"$add_below-$post->ID\", \"0\", \"$respond_id\", \"$post->ID\")'>$reply_text</a>";
+		$link = "<a rel='nofollow' class='comment-reply-link' href='" . get_the_permalink($post->ID) . "#$respond_id' onclick='return addComment.moveForm(\"$add_below-$post->ID\", \"0\", \"$respond_id\", \"$post->ID\")'>$reply_text</a>";
 	}
 	return apply_filters('post_comments_link', $before . $link . $after, $post);
 }
@@ -1624,8 +1624,8 @@
 	$defaults = array(
 		'fields'               => apply_filters( 'comment_form_default_fields', $fields ),
 		'comment_field'        => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun' ) . '</label> <textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea></p>',
-		'must_log_in'          => '<p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.' ), wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
-		'logged_in_as'         => '<p class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>' ), get_edit_user_link(), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
+		'must_log_in'          => '<p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.' ), wp_login_url( apply_filters( 'the_permalink', get_the_permalink( $post_id ) ) ) ) . '</p>',
+		'logged_in_as'         => '<p class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>' ), get_edit_user_link(), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_the_permalink( $post_id ) ) ) ) . '</p>',
 		'comment_notes_before' => '<p class="comment-notes">' . __( 'Your email address will not be published.' ) . ( $req ? $required_text : '' ) . '</p>',
 		'comment_notes_after'  => '<p class="form-allowed-tags">' . sprintf( __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s' ), ' <code>' . allowed_tags() . '</code>' ) . '</p>',
 		'id_form'              => 'commentform',
Index: wp-includes/category-template.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/category-template.php	(revision 24067)
+++ wp-includes/category-template.php	(revision )
@@ -457,7 +457,7 @@
 		}
 	} else {
 		if ( ! empty( $show_option_all ) ) {
-			$posts_page = ( 'page' == get_option( 'show_on_front' ) && get_option( 'page_for_posts' ) ) ? get_permalink( get_option( 'page_for_posts' ) ) : home_url( '/' );
+			$posts_page = ( 'page' == get_option( 'show_on_front' ) && get_option( 'page_for_posts' ) ) ? get_the_permalink( get_option( 'page_for_posts' ) ) : home_url( '/' );
 			$posts_page = esc_url( $posts_page );
 			if ( 'list' == $style )
 				$output .= "<li><a href='$posts_page'>$show_option_all</a></li>";
Index: wp-includes/comment.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/comment.php	(revision 24067)
+++ wp-includes/comment.php	(revision )
@@ -1854,7 +1854,7 @@
 		if ( $pingback_server_url ) {
 			@ set_time_limit( 60 );
 			 // Now, the RPC call
-			$pagelinkedfrom = get_permalink($post_ID);
+			$pagelinkedfrom = get_the_permalink($post_ID);
 
 			// using a timeout of 3 seconds should be enough to cover slow servers
 			$client = new WP_HTTP_IXR_Client($pingback_server_url);
@@ -1908,7 +1908,7 @@
 	$options['timeout'] = 4;
 	$options['body'] = array(
 		'title' => $title,
-		'url' => get_permalink($ID),
+		'url' => get_the_permalink($ID),
 		'blog_name' => get_option('blogname'),
 		'excerpt' => $excerpt
 	);
Index: wp-includes/theme-compat/comments-popup.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/theme-compat/comments-popup.php	(revision 24067)
+++ wp-includes/theme-compat/comments-popup.php	(revision )
@@ -68,7 +68,7 @@
 
 <form action="<?php echo get_option('siteurl'); ?>/wp-comments-post.php" method="post" id="commentform">
 <?php if ( $user_ID ) : ?>
-	<p><?php printf(__('Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out &raquo;</a>'), get_edit_user_link(), $user_identity, wp_logout_url(get_permalink())); ?></p>
+	<p><?php printf(__('Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out &raquo;</a>'), get_edit_user_link(), $user_identity, wp_logout_url(get_the_permalink())); ?></p>
 <?php else : ?>
 	<p>
 	  <input type="text" name="author" id="author" class="textarea" value="<?php echo esc_attr($comment_author); ?>" size="28" tabindex="1" />
Index: wp-admin/includes/class-wp-posts-list-table.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/class-wp-posts-list-table.php	(revision 24067)
+++ wp-admin/includes/class-wp-posts-list-table.php	(revision )
@@ -587,9 +587,9 @@
 				if ( $post_type_object->public ) {
 					if ( in_array( $post->post_status, array( 'pending', 'draft', 'future' ) ) ) {
 						if ( $can_edit_post )
-							$actions['view'] = '<a href="' . esc_url( apply_filters( 'preview_post_link', add_query_arg( 'preview', 'true', get_permalink( $post->ID ) ) ) ) . '" title="' . esc_attr( sprintf( __( 'Preview &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'Preview' ) . '</a>';
+							$actions['view'] = '<a href="' . esc_url( apply_filters( 'preview_post_link', add_query_arg( 'preview', 'true', get_the_permalink( $post->ID ) ) ) ) . '" title="' . esc_attr( sprintf( __( 'Preview &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'Preview' ) . '</a>';
 					} elseif ( 'trash' != $post->post_status ) {
-						$actions['view'] = '<a href="' . get_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
+						$actions['view'] = '<a href="' . get_the_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
 					}
 				}
 
Index: wp-includes/post-template.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/post-template.php	(revision 24067)
+++ wp-includes/post-template.php	(revision )
@@ -220,7 +220,7 @@
 			$output .= '<span id="more-' . $post->ID . '"></span>' . $content[1];
 		} else {
 			if ( ! empty( $more_link_text ) )
-				$output .= apply_filters( 'the_content_more_link', ' <a href="' . get_permalink() . "#more-{$post->ID}\" class=\"more-link\">$more_link_text</a>", $more_link_text );
+				$output .= apply_filters( 'the_content_more_link', ' <a href="' . get_the_permalink() . "#more-{$post->ID}\" class=\"more-link\">$more_link_text</a>", $more_link_text );
 			$output = force_balance_tags( $output );
 		}
 	}
@@ -706,14 +706,14 @@
 	$post = get_post();
 
 	if ( 1 == $i ) {
-		$url = get_permalink();
+		$url = get_the_permalink();
 	} else {
 		if ( '' == get_option('permalink_structure') || in_array($post->post_status, array('draft', 'pending')) )
-			$url = add_query_arg( 'page', $i, get_permalink() );
+			$url = add_query_arg( 'page', $i, get_the_permalink() );
 		elseif ( 'page' == get_option('show_on_front') && get_option('page_on_front') == $post->ID )
-			$url = trailingslashit(get_permalink()) . user_trailingslashit("$wp_rewrite->pagination_base/" . $i, 'single_paged');
+			$url = trailingslashit(get_the_permalink()) . user_trailingslashit("$wp_rewrite->pagination_base/" . $i, 'single_paged');
 		else
-			$url = trailingslashit(get_permalink()) . user_trailingslashit($i, 'single_paged');
+			$url = trailingslashit(get_the_permalink()) . user_trailingslashit($i, 'single_paged');
 	}
 
 	return '<a href="' . esc_url( $url ) . '">';
@@ -1058,7 +1058,7 @@
 
 		$css_class = implode( ' ', apply_filters( 'page_css_class', $css_class, $page, $depth, $args, $current_page ) );
 
-		$output .= $indent . '<li class="' . $css_class . '"><a href="' . get_permalink($page->ID) . '">' . $link_before . apply_filters( 'the_title', $page->post_title, $page->ID ) . $link_after . '</a>';
+		$output .= $indent . '<li class="' . $css_class . '"><a href="' . get_the_permalink($page->ID) . '">' . $link_before . apply_filters( 'the_title', $page->post_title, $page->ID ) . $link_after . '</a>';
 
 		if ( !empty($show_date) ) {
 			if ( 'modified' == $show_date )
Index: wp-admin/edit-form-advanced.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/edit-form-advanced.php	(revision 24067)
+++ wp-admin/edit-form-advanced.php	(revision )
@@ -32,32 +32,32 @@
 $messages = array();
 $messages['post'] = array(
 	 0 => '', // Unused. Messages start at index 1.
-	 1 => sprintf( __('Post updated. <a href="%s">View post</a>'), esc_url( get_permalink($post_ID) ) ),
+	 1 => sprintf( __('Post updated. <a href="%s">View post</a>'), esc_url( get_the_permalink($post_ID) ) ),
 	 2 => __('Custom field updated.'),
 	 3 => __('Custom field deleted.'),
 	 4 => __('Post updated.'),
 	/* translators: %s: date and time of the revision */
 	 5 => isset($_GET['revision']) ? sprintf( __('Post restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
-	 6 => sprintf( __('Post published. <a href="%s">View post</a>'), esc_url( get_permalink($post_ID) ) ),
+	 6 => sprintf( __('Post published. <a href="%s">View post</a>'), esc_url( get_the_permalink($post_ID) ) ),
 	 7 => __('Post saved.'),
-	 8 => sprintf( __('Post submitted. <a target="_blank" href="%s">Preview post</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
+	 8 => sprintf( __('Post submitted. <a target="_blank" href="%s">Preview post</a>'), esc_url( add_query_arg( 'preview', 'true', get_the_permalink($post_ID) ) ) ),
 	 9 => sprintf( __('Post scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview post</a>'),
 		// translators: Publish box date format, see http://php.net/date
-		date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
-	10 => sprintf( __('Post draft updated. <a target="_blank" href="%s">Preview post</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
+		date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_the_permalink($post_ID) ) ),
+	10 => sprintf( __('Post draft updated. <a target="_blank" href="%s">Preview post</a>'), esc_url( add_query_arg( 'preview', 'true', get_the_permalink($post_ID) ) ) ),
 );
 $messages['page'] = array(
 	 0 => '', // Unused. Messages start at index 1.
-	 1 => sprintf( __('Page updated. <a href="%s">View page</a>'), esc_url( get_permalink($post_ID) ) ),
+	 1 => sprintf( __('Page updated. <a href="%s">View page</a>'), esc_url( get_the_permalink($post_ID) ) ),
 	 2 => __('Custom field updated.'),
 	 3 => __('Custom field deleted.'),
 	 4 => __('Page updated.'),
 	 5 => isset($_GET['revision']) ? sprintf( __('Page restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
-	 6 => sprintf( __('Page published. <a href="%s">View page</a>'), esc_url( get_permalink($post_ID) ) ),
+	 6 => sprintf( __('Page published. <a href="%s">View page</a>'), esc_url( get_the_permalink($post_ID) ) ),
 	 7 => __('Page saved.'),
-	 8 => sprintf( __('Page submitted. <a target="_blank" href="%s">Preview page</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
-	 9 => sprintf( __('Page scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview page</a>'), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
-	10 => sprintf( __('Page draft updated. <a target="_blank" href="%s">Preview page</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
+	 8 => sprintf( __('Page submitted. <a target="_blank" href="%s">Preview page</a>'), esc_url( add_query_arg( 'preview', 'true', get_the_permalink($post_ID) ) ) ),
+	 9 => sprintf( __('Page scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview page</a>'), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_the_permalink($post_ID) ) ),
+	10 => sprintf( __('Page draft updated. <a target="_blank" href="%s">Preview page</a>'), esc_url( add_query_arg( 'preview', 'true', get_the_permalink($post_ID) ) ) ),
 );
 $messages['attachment'] = array_fill( 1, 10, __( 'Media attachment updated.' ) ); // Hack, for now.
 
Index: wp-admin/includes/media.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/media.php	(revision 24067)
+++ wp-admin/includes/media.php	(revision )
@@ -1189,7 +1189,7 @@
 		$image_edit_button = "<input type='button' id='imgedit-open-btn-$post->ID' onclick='imageEdit.open( $post->ID, \"$nonce\" )' class='button' value='" . esc_attr__( 'Edit Image' ) . "' /> <span class='spinner'></span>";
 	}
 
-	$attachment_url = get_permalink( $attachment_id );
+	$attachment_url = get_the_permalink( $attachment_id );
 
 	$item = "
 	$type_html
Index: wp-admin/includes/dashboard.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/dashboard.php	(revision 24067)
+++ wp-admin/includes/dashboard.php	(revision )
@@ -461,7 +461,7 @@
 
 	$drafts = false;
 	if ( 'post' === strtolower( $_SERVER['REQUEST_METHOD'] ) && isset( $_POST['action'] ) && 0 === strpos( $_POST['action'], 'post-quickpress' ) && (int) $_POST['post_ID'] ) {
-		$view = get_permalink( $_POST['post_ID'] );
+		$view = get_the_permalink( $_POST['post_ID'] );
 		$edit = esc_url( get_edit_post_link( $_POST['post_ID'] ) );
 		if ( 'post-quickpress-publish' == $_POST['action'] ) {
 			if ( current_user_can('publish_posts') )
Index: wp-includes/query.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/query.php	(revision 24067)
+++ wp-includes/query.php	(revision )
@@ -3612,7 +3612,7 @@
 		if ( ! $id )
 			return;
 
-		$link = get_permalink($id);
+		$link = get_the_permalink($id);
 
 		if ( !$link )
 			return;
Index: wp-includes/general-template.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/general-template.php	(revision 24067)
+++ wp-includes/general-template.php	(revision )
@@ -1055,7 +1055,7 @@
 		if ( $results ) {
 			foreach ( (array) $results as $result ) {
 				if ( $result->post_date != '0000-00-00 00:00:00' ) {
-					$url  = get_permalink( $result );
+					$url  = get_the_permalink( $result );
 					if ( $result->post_title )
 						$text = strip_tags( apply_filters( 'the_title', $result->post_title, $result->ID ) );
 					else
Index: wp-admin/includes/meta-boxes.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/meta-boxes.php	(revision 24067)
+++ wp-admin/includes/meta-boxes.php	(revision )
@@ -38,10 +38,10 @@
 <div id="preview-action">
 <?php
 if ( 'publish' == $post->post_status ) {
-	$preview_link = esc_url( get_permalink( $post->ID ) );
+	$preview_link = esc_url( get_the_permalink( $post->ID ) );
 	$preview_button = __( 'Preview Changes' );
 } else {
-	$preview_link = set_url_scheme( get_permalink( $post->ID ) );
+	$preview_link = set_url_scheme( get_the_permalink( $post->ID ) );
 	$preview_link = esc_url( apply_filters( 'preview_post_link', add_query_arg( 'preview', 'true', $preview_link ) ) );
 	$preview_button = __( 'Preview' );
 }
\ No newline at end of file
Index: wp-includes/class-wp-editor.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/class-wp-editor.php	(revision 24067)
+++ wp-includes/class-wp-editor.php	(revision )
@@ -800,7 +800,7 @@
 			$results[] = array(
 				'ID' => $post->ID,
 				'title' => trim( esc_html( strip_tags( get_the_title( $post ) ) ) ),
-				'permalink' => get_permalink( $post->ID ),
+				'permalink' => get_the_permalink( $post->ID ),
 				'info' => $info,
 			);
 		}
Index: wp-admin/press-this.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/press-this.php	(revision 24067)
+++ wp-admin/press-this.php	(revision )
@@ -574,7 +574,7 @@
 			$post_ID = intval($posted); ?>
 			<div id="message" class="updated">
 			<p><strong><?php _e('Your post has been saved.'); ?></strong>
-			<a onclick="window.opener.location.replace(this.href); window.close();" href="<?php echo get_permalink($post_ID); ?>"><?php _e('View post'); ?></a>
+			<a onclick="window.opener.location.replace(this.href); window.close();" href="<?php echo get_the_permalink($post_ID); ?>"><?php _e('View post'); ?></a>
 			| <a href="<?php echo get_edit_post_link( $post_ID ); ?>" onclick="window.opener.location.replace(this.href); window.close();"><?php _e('Edit Post'); ?></a>
 			| <a href="#" onclick="window.close();"><?php _e('Close Window'); ?></a></p>
 			</div>
Index: wp-includes/feed.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/feed.php	(revision 24067)
+++ wp-includes/feed.php	(revision )
@@ -188,7 +188,7 @@
  * @uses apply_filters() Call 'the_permalink_rss' on the post permalink
  */
 function the_permalink_rss() {
-	echo esc_url( apply_filters('the_permalink_rss', get_permalink() ));
+	echo esc_url( apply_filters('the_permalink_rss', get_the_permalink() ));
 }
 
 /**
Index: wp-includes/post.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/post.php	(revision 24067)
+++ wp-includes/post.php	(revision )
@@ -2845,7 +2845,7 @@
 
 	// Set GUID
 	if ( !$update && '' == $current_guid )
-		$wpdb->update( $wpdb->posts, array( 'guid' => get_permalink( $post_ID ) ), $where );
+		$wpdb->update( $wpdb->posts, array( 'guid' => get_the_permalink( $post_ID ) ), $where );
 
 	clean_post_cache( $post_ID );
 
@@ -4757,7 +4757,7 @@
 	if ( $old_status != 'publish' && $new_status == 'publish' ) {
 		// Reset GUID if transitioning to publish and it is empty
 		if ( '' == get_the_guid($post->ID) )
-			$wpdb->update( $wpdb->posts, array( 'guid' => get_permalink( $post->ID ) ), array( 'ID' => $post->ID ) );
+			$wpdb->update( $wpdb->posts, array( 'guid' => get_the_permalink( $post->ID ) ), array( 'ID' => $post->ID ) );
 		do_action('private_to_published', $post->ID);  // Deprecated, use private_to_publish
 	}
 
Index: wp-includes/pluggable.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/pluggable.php	(revision 24067)
+++ wp-includes/pluggable.php	(revision )
@@ -1045,8 +1045,8 @@
 		/* translators: 1: blog name, 2: post title */
 		$subject = sprintf( __('[%1$s] Pingback: "%2$s"'), $blogname, $post->post_title );
 	}
-	$notify_message .= get_permalink($comment->comment_post_ID) . "#comments\r\n\r\n";
-	$notify_message .= sprintf( __('Permalink: %s'), get_permalink( $comment->comment_post_ID ) . '#comment-' . $comment_id ) . "\r\n";
+	$notify_message .= get_the_permalink($comment->comment_post_ID) . "#comments\r\n\r\n";
+	$notify_message .= sprintf( __('Permalink: %s'), get_the_permalink( $comment->comment_post_ID ) . '#comment-' . $comment_id ) . "\r\n";
 	if ( EMPTY_TRASH_DAYS )
 		$notify_message .= sprintf( __('Trash it: %s'), admin_url("comment.php?action=trash&c=$comment_id") ) . "\r\n";
 	else
@@ -1116,21 +1116,21 @@
 	{
 		case 'trackback':
 			$notify_message  = sprintf( __('A new trackback on the post "%s" is waiting for your approval'), $post->post_title ) . "\r\n";
-			$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
+			$notify_message .= get_the_permalink($comment->comment_post_ID) . "\r\n\r\n";
 			$notify_message .= sprintf( __('Website : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 			$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
 			$notify_message .= __('Trackback excerpt: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
 			break;
 		case 'pingback':
 			$notify_message  = sprintf( __('A new pingback on the post "%s" is waiting for your approval'), $post->post_title ) . "\r\n";
-			$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
+			$notify_message .= get_the_permalink($comment->comment_post_ID) . "\r\n\r\n";
 			$notify_message .= sprintf( __('Website : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 			$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
 			$notify_message .= __('Pingback excerpt: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
 			break;
 		default: //Comments
 			$notify_message  = sprintf( __('A new comment on the post "%s" is waiting for your approval'), $post->post_title ) . "\r\n";
-			$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
+			$notify_message .= get_the_permalink($comment->comment_post_ID) . "\r\n\r\n";
 			$notify_message .= sprintf( __('Author : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 			$notify_message .= sprintf( __('E-mail : %s'), $comment->comment_author_email ) . "\r\n";
 			$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
Index: wp-admin/includes/class-wp-media-list-table.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/class-wp-media-list-table.php	(revision 24067)
+++ wp-admin/includes/class-wp-media-list-table.php	(revision )
@@ -404,7 +404,7 @@
 					$delete_ays = !MEDIA_TRASH ? " onclick='return showNotice.warn();'" : '';
 					$actions['delete'] = "<a class='submitdelete'$delete_ays href='" . wp_nonce_url( "post.php?action=delete&amp;post=$post->ID", 'delete-post_' . $post->ID ) . "'>" . __( 'Delete Permanently' ) . "</a>";
 				}
-			$actions['view'] = '<a href="' . get_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $att_title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
+			$actions['view'] = '<a href="' . get_the_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $att_title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
 			if ( current_user_can( 'edit_post', $post->ID ) )
 				$actions['attach'] = '<a href="#the-list" onclick="findPosts.open( \'media[]\',\''.$post->ID.'\' );return false;" class="hide-if-no-js">'.__( 'Attach' ).'</a>';
 		}
@@ -423,7 +423,7 @@
 			}
 			if ( !$this->is_trash ) {
 				$title =_draft_or_post_title( $post->post_parent );
-				$actions['view'] = '<a href="' . get_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
+				$actions['view'] = '<a href="' . get_the_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
 			}
 		}
 
Index: wp-admin/includes/ajax-actions.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/ajax-actions.php	(revision 24067)
+++ wp-admin/includes/ajax-actions.php	(revision )
@@ -1274,7 +1274,7 @@
 function wp_ajax_get_permalink() {
 	check_ajax_referer( 'getpermalink', 'getpermalinknonce' );
 	$post_id = isset($_POST['post_id'])? intval($_POST['post_id']) : 0;
-	wp_die( add_query_arg( array( 'preview' => 'true' ), get_permalink( $post_id ) ) );
+	wp_die( add_query_arg( array( 'preview' => 'true' ), get_the_permalink( $post_id ) ) );
 }
 
 function wp_ajax_sample_permalink() {
Index: wp-includes/post-formats.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/post-formats.php	(revision 24067)
+++ wp-includes/post-formats.php	(revision )
@@ -907,7 +907,7 @@
 			$output .= '<span id="more-' . $post->ID . '"></span>' . $content[1];
 		} else {
 			if ( ! empty( $more_link_text ) )
-				$output .= apply_filters( 'the_content_more_link', ' <a href="' . get_permalink() . "#more-{$post->ID}\" class=\"more-link\">$more_link_text</a>", $more_link_text );
+				$output .= apply_filters( 'the_content_more_link', ' <a href="' . get_the_permalink() . "#more-{$post->ID}\" class=\"more-link\">$more_link_text</a>", $more_link_text );
 
 			$output = force_balance_tags( $output );
 		}
\ No newline at end of file
Index: wp-trackback.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-trackback.php	(revision 24067)
+++ wp-trackback.php	(revision )
@@ -77,7 +77,7 @@
 
 if (empty($title) && empty($tb_url) && empty($blog_name)) {
 	// If it doesn't look like a trackback at all...
-	wp_redirect(get_permalink($tb_id));
+	wp_redirect(get_the_permalink($tb_id));
 	exit;
 }
 
Index: wp-includes/canonical.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/canonical.php	(revision 24067)
+++ wp-includes/canonical.php	(revision )
@@ -83,7 +83,7 @@
 			if ( 'revision' == $vars->post_type && $vars->post_parent > 0 )
 				$id = $vars->post_parent;
 
-			if ( $redirect_url = get_permalink($id) )
+			if ( $redirect_url = get_the_permalink($id) )
 				$redirect['query'] = _remove_qs_args_if_not_in_url( $redirect['query'], array( 'p', 'page_id', 'attachment_id', 'pagename', 'name', 'post_type' ), $redirect_url );
 		}
 	}
@@ -96,7 +96,7 @@
 		if ( $id && $redirect_post = get_post($id) ) {
 			$post_type_obj = get_post_type_object($redirect_post->post_type);
 			if ( $post_type_obj->public ) {
-				$redirect_url = get_permalink($redirect_post);
+				$redirect_url = get_the_permalink($redirect_post);
 				$redirect['query'] = _remove_qs_args_if_not_in_url( $redirect['query'], array( 'p', 'page_id', 'attachment_id', 'pagename', 'name', 'post_type' ), $redirect_url );
 			}
 		}
@@ -113,18 +113,18 @@
 			if ( $redirect_url = get_attachment_link(get_query_var('attachment_id')) )
 				$redirect['query'] = remove_query_arg('attachment_id', $redirect['query']);
 		} elseif ( is_single() && !empty($_GET['p']) && ! $redirect_url ) {
-			if ( $redirect_url = get_permalink(get_query_var('p')) )
+			if ( $redirect_url = get_the_permalink(get_query_var('p')) )
 				$redirect['query'] = remove_query_arg(array('p', 'post_type'), $redirect['query']);
 		} elseif ( is_single() && !empty($_GET['name'])  && ! $redirect_url ) {
-			if ( $redirect_url = get_permalink( $wp_query->get_queried_object_id() ) )
+			if ( $redirect_url = get_the_permalink( $wp_query->get_queried_object_id() ) )
 				$redirect['query'] = remove_query_arg('name', $redirect['query']);
 		} elseif ( is_page() && !empty($_GET['page_id']) && ! $redirect_url ) {
-			if ( $redirect_url = get_permalink(get_query_var('page_id')) )
+			if ( $redirect_url = get_the_permalink(get_query_var('page_id')) )
 				$redirect['query'] = remove_query_arg('page_id', $redirect['query']);
 		} elseif ( is_page() && !is_feed() && isset($wp_query->queried_object) && 'page' == get_option('show_on_front') && $wp_query->queried_object->ID == get_option('page_on_front')  && ! $redirect_url ) {
 			$redirect_url = home_url('/');
 		} elseif ( is_home() && !empty($_GET['page_id']) && 'page' == get_option('show_on_front') && get_query_var('page_id') == get_option('page_for_posts')  && ! $redirect_url ) {
-			if ( $redirect_url = get_permalink(get_option('page_for_posts')) )
+			if ( $redirect_url = get_the_permalink(get_option('page_for_posts')) )
 				$redirect['query'] = remove_query_arg('page_id', $redirect['query']);
 		} elseif ( !empty($_GET['m']) && ( is_year() || is_month() || is_day() ) ) {
 			$m = get_query_var('m');
@@ -207,13 +207,13 @@
 			$category = get_category_by_path( $cat );
 			$post_terms = wp_get_object_terms($wp_query->get_queried_object_id(), 'category', array('fields' => 'tt_ids'));
 			if ( (!$category || is_wp_error($category)) || ( !is_wp_error($post_terms) && !empty($post_terms) && !in_array($category->term_taxonomy_id, $post_terms) ) )
-				$redirect_url = get_permalink($wp_query->get_queried_object_id());
+				$redirect_url = get_the_permalink($wp_query->get_queried_object_id());
 		}
 
 		// Post Paging
 		if ( is_singular() && ! is_front_page() && get_query_var('page') ) {
 			if ( !$redirect_url )
-				$redirect_url = get_permalink( get_queried_object_id() );
+				$redirect_url = get_the_permalink( get_queried_object_id() );
 			$redirect_url = trailingslashit( $redirect_url ) . user_trailingslashit( get_query_var( 'page' ), 'single_paged' );
 			$redirect['query'] = remove_query_arg( 'page', $redirect['query'] );
 		}
@@ -495,9 +495,9 @@
 		if ( get_query_var( 'feed' ) )
 			return get_post_comments_feed_link( $post_id, get_query_var( 'feed' ) );
 		elseif ( get_query_var( 'page' ) )
-			return trailingslashit( get_permalink( $post_id ) ) . user_trailingslashit( get_query_var( 'page' ), 'single_paged' );
+			return trailingslashit( get_the_permalink( $post_id ) ) . user_trailingslashit( get_query_var( 'page' ), 'single_paged' );
 		else
-			return get_permalink( $post_id );
+			return get_the_permalink( $post_id );
 	}
 
 	return false;
Index: wp-admin/includes/upgrade.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/upgrade.php	(revision 24067)
+++ wp-admin/includes/upgrade.php	(revision )
@@ -557,7 +557,7 @@
 			$post_title = addslashes(deslash($post->post_title));
 			$post_excerpt = addslashes(deslash($post->post_excerpt));
 			if ( empty($post->guid) )
-				$guid = get_permalink($post->ID);
+				$guid = get_the_permalink($post->ID);
 			else
 				$guid = $post->guid;
 
Index: wp-includes/ms-functions.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/ms-functions.php	(revision 24067)
+++ wp-includes/ms-functions.php	(revision )
@@ -311,7 +311,7 @@
  */
 function get_blog_permalink( $blog_id, $post_id ) {
 	switch_to_blog( $blog_id );
-	$link = get_permalink( $post_id );
+	$link = get_the_permalink( $post_id );
 	restore_current_blog();
 
 	return $link;
Index: wp-includes/deprecated.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/deprecated.php	(revision 24067)
+++ wp-includes/deprecated.php	(revision )
@@ -147,7 +147,7 @@
 	if ( !$post )
 		return;
 
-	$string = '<a href="'.get_permalink($post->ID).'">'.$previous;
+	$string = '<a href="'.get_the_permalink($post->ID).'">'.$previous;
 	if ( 'yes' == $title )
 		$string .= apply_filters('the_title', $post->post_title, $post->ID);
 	$string .= '</a>';
@@ -183,7 +183,7 @@
 	if ( !$post	)
 		return;
 
-	$string = '<a href="'.get_permalink($post->ID).'">'.$next;
+	$string = '<a href="'.get_the_permalink($post->ID).'">'.$next;
 	if ( 'yes' == $title )
 		$string .= apply_filters('the_title', $post->post_title, $post->ID);
 	$string .= '</a>';
@@ -2739,7 +2739,7 @@
 
 	$link = $start ? "<link rel='start' title='" : "<link rel='end' title='";
 	$link .= esc_attr($title);
-	$link .= "' href='" . get_permalink($post) . "' />\n";
+	$link .= "' href='" . get_the_permalink($post) . "' />\n";
 
 	$boundary = $start ? 'start' : 'end';
 	return apply_filters( "{$boundary}_post_rel_link", $link );
@@ -2814,7 +2814,7 @@
 
 	$link = "<link rel='up' title='";
 	$link .= esc_attr( $title );
-	$link .= "' href='" . get_permalink($post) . "' />\n";
+	$link .= "' href='" . get_the_permalink($post) . "' />\n";
 
 	return apply_filters( "parent_post_rel_link", $link );
 }
Index: wp-includes/nav-menu.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/nav-menu.php	(revision 24067)
+++ wp-includes/nav-menu.php	(revision )
@@ -594,7 +594,7 @@
 					$menu_item->_invalid = true;
 				}
 
-				$menu_item->url = get_permalink( $menu_item->object_id );
+				$menu_item->url = get_the_permalink( $menu_item->object_id );
 
 				$original_object = get_post( $menu_item->object_id );
 				$original_title = $original_object->post_title;
@@ -643,7 +643,7 @@
 			$menu_item->type_label = $object->labels->singular_name;
 
 			$menu_item->title = $menu_item->post_title;
-			$menu_item->url = get_permalink( $menu_item->ID );
+			$menu_item->url = get_the_permalink( $menu_item->ID );
 			$menu_item->target = '';
 
 			$menu_item->attr_title = apply_filters( 'nav_menu_attr_title', '' );
Index: wp-admin/includes/class-wp-comments-list-table.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/class-wp-comments-list-table.php	(revision 24067)
+++ wp-admin/includes/class-wp-comments-list-table.php	(revision )
@@ -504,7 +504,7 @@
 		$this->comments_bubble( $post->ID, $pending_comments );
 		echo '</span> ';
 		$post_type_object = get_post_type_object( $post->post_type );
-		echo "<a href='" . get_permalink( $post->ID ) . "'>" . $post_type_object->labels->view_item . '</a>';
+		echo "<a href='" . get_the_permalink( $post->ID ) . "'>" . $post_type_object->labels->view_item . '</a>';
 		echo '</div>';
 		if ( 'attachment' == $post->post_type && ( $thumb = wp_get_attachment_image( $post->ID, array( 80, 60 ), true ) ) )
 			echo $thumb;
Index: wp-includes/admin-bar.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/admin-bar.php	(revision 24067)
+++ wp-includes/admin-bar.php	(revision )
@@ -438,7 +438,7 @@
 			$wp_admin_bar->add_menu( array(
 				'id' => 'view',
 				'title' => $post_type_object->labels->view_item,
-				'href' => get_permalink( $post->ID )
+				'href' => get_the_permalink( $post->ID )
 			) );
 		} elseif ( 'edit-tags' == $current_screen->base
 			&& isset( $tag ) && is_object( $tag )
Index: wp-includes/theme-compat/comments.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/theme-compat/comments.php	(revision 24067)
+++ wp-includes/theme-compat/comments.php	(revision )
@@ -62,14 +62,14 @@
 </div>
 
 <?php if ( get_option('comment_registration') && !is_user_logged_in() ) : ?>
-<p><?php printf(__('You must be <a href="%s">logged in</a> to post a comment.'), wp_login_url( get_permalink() )); ?></p>
+<p><?php printf(__('You must be <a href="%s">logged in</a> to post a comment.'), wp_login_url( get_the_permalink() )); ?></p>
 <?php else : ?>
 
 <form action="<?php echo get_option('siteurl'); ?>/wp-comments-post.php" method="post" id="commentform">
 
 <?php if ( is_user_logged_in() ) : ?>
 
-<p><?php printf(__('Logged in as <a href="%1$s">%2$s</a>.'), get_edit_user_link(), $user_identity); ?> <a href="<?php echo wp_logout_url(get_permalink()); ?>" title="<?php esc_attr_e('Log out of this account'); ?>"><?php _e('Log out &raquo;'); ?></a></p>
+<p><?php printf(__('Logged in as <a href="%1$s">%2$s</a>.'), get_edit_user_link(), $user_identity); ?> <a href="<?php echo wp_logout_url(get_the_permalink()); ?>" title="<?php esc_attr_e('Log out of this account'); ?>"><?php _e('Log out &raquo;'); ?></a></p>
 
 <?php else : ?>
 

Index: wp-admin/includes/post.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/post.php	(revision 24067)
+++ wp-admin/includes/post.php	(revision )
@@ -995,7 +995,7 @@
 	$original_date = $post->post_date;
 	$original_name = $post->post_name;
 
 	// Hack: get_permalink would return ugly permalink for
 	// drafts, so we will fake, that our post is published
 	if ( in_array($post->post_status, array('draft', 'pending')) ) {
 		$post->post_status = 'publish';
@@ -1011,7 +1011,7 @@
 
 	$post->filter = 'sample';
 
-	$permalink = get_permalink($post, true);
+	$permalink = get_the_permalink($post, true);
 
 	// Replace custom post_type Token with generic pagename token for ease of use.
 	$permalink = str_replace("%$post->post_type%", '%pagename%', $permalink);
@@ -1212,7 +1212,7 @@
 	<?php
 
 	if ( $locked ) {
-		$preview_link = set_url_scheme( add_query_arg( 'preview', 'true', get_permalink( $post->ID ) ) );
+		$preview_link = set_url_scheme( add_query_arg( 'preview', 'true', get_the_permalink( $post->ID ) ) );
 
 		if ( 'publish' == $post->post_status || $user->ID != $post->post_author ) {
 			// Latest content is in autosave
@@ -1378,10 +1378,10 @@
 		wp_die( $id->get_error_message() );
 
 	if ( $_POST['post_status'] == 'draft' && $user_id == $post->post_author ) {
-		$url = add_query_arg( 'preview', 'true', get_permalink($id) );
+		$url = add_query_arg( 'preview', 'true', get_the_permalink($id) );
 	} else {
 		$nonce = wp_create_nonce('post_preview_' . $id);
-		$url = add_query_arg( array( 'preview' => 'true', 'preview_id' => $id, 'preview_nonce' => $nonce ), get_permalink($id) );
+		$url = add_query_arg( array( 'preview' => 'true', 'preview_id' => $id, 'preview_nonce' => $nonce ), get_the_permalink($id) );
 	}
 
 	return apply_filters( 'preview_post_link', $url );
@@ -995,7 +995,7 @@
 	$original_name = $post->post_name;
 
-	// Hack: get_permalink would return ugly permalink for
+	// Hack: get_the_permalink would return ugly permalink for
 	// drafts, so we will fake, that our post is published
 	if ( in_array($post->post_status, array('draft', 'pending')) ) {